@@ -60,9 +60,9 @@
 #' plot(tree)
 #'
 
-hclustvar <- function(X.quanti=NULL, X.quali=NULL, init=NULL) {
+hclustvar <- function(X.quanti = NULL, X.quali = NULL, init = NULL) {
   cl <- match.call()
-  rec <- PCAmixdata::recod(X.quanti,X.quali,rename.level=TRUE)
+  rec <- PCAmixdata::recod(X.quanti, X.quali, rename.level = TRUE)
   X <- rec$X     
   Z <- rec$Z		
   indexj <- rec$indexj 
@@ -88,19 +88,19 @@ hclustvar <- function(X.quanti=NULL, X.quali=NULL, init=NULL) {
   order <- rep(0, p)                         # R-compatible order for plotting
   
   diss<-matrix(0,p,p)
-  debut <- Sys.time()
+  #debut <- Sys.time()
   for (i in 1:(p-1)) {
     a <- i+1
     for (j in a:p) {
       A <- which(init==i)
       B <- which(init==j)
-      matA<-Z[,which(is.element(indexj,A))]
+      matA <- Z[,which(is.element(indexj,A))]
       matB <- Z[,which(is.element(indexj,B))]
       diss[i,j] <-clust_diss(matA,matB)
       diss[j,i] <- diss[i,j]
     }   
   }
-  Sys.time()-debut
+  #Sys.time()-debut
   
   nnsnnsdiss <- getnnsvar(diss, flag)           # call to function getnns
   clusmat <- matrix(0, p, p)                 # cluster memberships
@@ -219,7 +219,9 @@ hclustvar <- function(X.quanti=NULL, X.quali=NULL, init=NULL) {
   xcall <- "hierclust(X)"
   class(xcall) <- "call"
   
-  retlist <- list(call = cl,rec=rec,init=init,merge=merge,height=lev[(p-1):1],order=orderlist,labels=labels,clusmat=clusmat,X.quanti=X.quanti,X.quali=X.quali)
+  retlist <- list(call = cl, rec = rec, init = init, merge = merge, height = lev[(p-1):1],
+                  order = orderlist, labels = labels, clusmat = clusmat, X.quanti = rec$X.quanti,
+                  X.quali = rec$X.quali)
   class(retlist) <- c("hclustvar","hclust")
   retlist
 }
